@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- * $Id: classlist.cpp,v 1.14 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ *
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -24,6 +24,7 @@
 #include "vhdldocgen.h"
 #include "defargs.h"
 #include "arguments.h"
+#include "groupdef.h"
 
 ClassList::ClassList() : QList<ClassDef>()
 {
@@ -33,30 +34,25 @@ ClassList::~ClassList()
 {
 }
 
-static int compItems(void *item1,void *item2)
+static int compItems(const ClassDef *c1,const ClassDef *c2)
 {
-  ClassDef *c1=(ClassDef *)item1;
-  ClassDef *c2=(ClassDef *)item2;
   static bool b = Config_getBool("SORT_BY_SCOPE_NAME");
-  //printf("compItems: %d %s<->%s\n",b,c1->name().data(),c2->name().data());
-  if (b) 
-  { 
-     return stricmp(c1->name(),
-                    c2->name());
+  if (b)
+  {
+     return qstricmp(c1->name(), c2->name());
   }
   else
   {
-     return stricmp(c1->className(),
-                    c2->className());
+     return qstricmp(c1->className(), c2->className());
   }
 }
 
-int ClassList::compareItems(GCI item1, GCI item2)
+int ClassList::compareValues(const ClassDef *item1, const ClassDef *item2) const
 {
   return compItems(item1,item2);
 }
 
-int ClassSDict::compareItems(GCI item1, GCI item2)
+int ClassSDict::compareValues(const ClassDef *item1, const ClassDef *item2) const
 {
   return compItems(item1,item2);
 }
@@ -76,13 +72,13 @@ bool ClassSDict::declVisible(const ClassDef::CompoundType *filter) const
     ClassDef *cd=0;
     for (sdi.toFirst();(cd=sdi.current());++sdi)
     {
-      if (cd->name().find('@')==-1 && 
+      if (cd->name().find('@')==-1 &&
           (filter==0 || *filter==cd->compoundType())
          )
       {
         bool isLink = cd->isLinkable();
-        if (isLink || 
-             (!hideUndocClasses && 
+        if (isLink ||
+             (!hideUndocClasses &&
               (!cd->isLocal() || extractLocalClasses)
              )
            )
@@ -107,8 +103,8 @@ void ClassSDict::writeDeclaration(OutputList &ol,const ClassDef::CompoundType *f
     for (sdi.toFirst();(cd=sdi.current());++sdi)
     {
       //printf("  ClassSDict::writeDeclaration for %s\n",cd->name().data());
-      if (cd->name().find('@')==-1 && 
-          !cd->isExtension() && 
+      if (cd->name().find('@')==-1 &&
+          !cd->isExtension() &&
           (cd->protection()!=Private || extractPrivate) &&
           (filter==0 || *filter==cd->compoundType())
          )
@@ -119,7 +115,7 @@ void ClassSDict::writeDeclaration(OutputList &ol,const ClassDef::CompoundType *f
     if (found) ol.endMemberList();
   }
 }
-  
+
 void ClassSDict::writeDocumentation(OutputList &ol,Definition * container)
 {
   static bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
@@ -136,21 +132,17 @@ void ClassSDict::writeDocumentation(OutputList &ol,Definition * container)
     ClassDef *cd=0;
     for (sdi.toFirst();(cd=sdi.current());++sdi)
     {
-      //printf("%s:writeDocumentation() %p embedded=%d container=%p\n",
-      //  cd->name().data(),cd->getOuterScope(),cd->isEmbeddedInOuterScope(),
-      //  container);
+      //printf("%s:writeDocumentation() %p linkable=%d embedded=%d container=%p partOfGroups=%d\n",
+      //  cd->name().data(),cd->getOuterScope(),cd->isLinkableInProject(),cd->isEmbeddedInOuterScope(),
+      //  container,cd->partOfGroups() ? cd->partOfGroups()->count() : 0);
 
-      if (cd->name().find('@')==-1 && 
+      if (cd->name().find('@')==-1 &&
           cd->isLinkableInProject() &&
           cd->isEmbeddedInOuterScope() &&
           (container==0 || cd->partOfGroups()==0) // if container==0 -> show as part of the group docs, otherwise only show if not part of a group
-          //&&
-          //(container==0 || // no container -> used for groups
-          // cd->getOuterScope()==container || // correct container -> used for namespaces and classes
-          // (container->definitionType()==Definition::TypeFile && cd->getOuterScope()==Doxygen::globalScope && cd->partOfGroups()==0) // non grouped class with file scope -> used for files
-          //)
          )
       {
+        //printf("  showing class %s\n",cd->name().data());
         if (!found)
         {
           ol.writeRuler();
