@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: htmlhelp.h,v 1.7 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,15 +21,17 @@
 #ifndef HTMLHELP_H
 #define HTMLHELP_H
 
-#include "qtbc.h"
-#include <qtextstream.h>
 #include <qstrlist.h>
+#include <qdict.h>
 #include "index.h"
+#include "ftextstream.h"
 
 class QFile;
+class Definition;
 class HtmlHelpIndex;
 
-/*! A class that generated the HTML Help specific files.
+/** A class that generated the HTML Help specific files.
+ *
  *  These files can be used with the Microsoft HTML Help workshop
  *  to generate compressed HTML files (.chm).
  */
@@ -64,30 +66,39 @@ class HtmlHelp  : public IndexIntf
   public:
     //static HtmlHelp *getInstance();
     HtmlHelp();
+    ~HtmlHelp();
     void initialize();
     void finalize();
     void incContentsDepth();
     void decContentsDepth();
     void addContentsItem(bool isDir,
                          const char *name, 
-                         const char *ref = 0, 
-                         const char *file = 0,
-                         const char *anchor = 0);
-    void addIndexItem(const char *level1, const char *level2, 
-                      const char *contRef, const char *memRef,
-                      const char *anchor);
+                         const char *ref, 
+                         const char *file,
+                         const char *anchor,
+                         bool separateIndex,
+                         bool addToNavIndex,
+                         Definition *def);
+    void addIndexItem(Definition *context,MemberDef *md,
+                      const char *sectionAnchor, const char *title);
     void addIndexFile(const char *name);
+    void addImageFile(const char *);
+    void addStyleSheetFile(const char *) {}
 
   private:
+    friend class HtmlHelpIndex;
     void createProjectFile();
 
     QFile *cf,*kf; 
-    QTextStream cts,kts;
+    FTextStream cts,kts;
     HtmlHelpIndex *index;
     int dc;
     QStrList indexFiles;
+    QStrList imageFiles;
     QDict<void> indexFileDict;
     static HtmlHelp *theInstance;
+    QCString recode(const QCString &s);
+    void *m_fromUtf8;
 };
 
 #endif /* HTMLHELP_H */
