@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,14 +19,14 @@
  * 15 Dec 2001 : Translation to greek by
  *               Harry Kalogirou <no email>
  *
- * 01 Jan 2009 : Greek maintainance by
+ * 01 Jan 2009 : Greek maintenance by
  *               Paul Gessos <gessos.paul@yahoo.gr>
  */
 
 #ifndef TRANSLATOR_GR_H
 #define TRANSLATOR_GR_H
 
-class TranslatorGreek : public Translator
+class TranslatorGreek : public TranslatorAdapter_1_8_4
 {
   public:
 
@@ -47,12 +47,6 @@ class TranslatorGreek : public Translator
       return "\\usepackage[greek,english]{babel}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-        return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -394,12 +388,6 @@ class TranslatorGreek : public Translator
     virtual QCString trDefines()
     { return "Ορισμοί"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Πρωτοτυπήσεις Συναρτήσεων"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -436,12 +424,6 @@ class TranslatorGreek : public Translator
     virtual QCString trDefineDocumentation()
     { return "Τεκμηρίωση Ορισμών"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Τεκμηρίωση Πρωτοτυπήσεων των Συναρτήσεων"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -491,12 +473,6 @@ class TranslatorGreek : public Translator
       result+=(QCString)" από";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "γραμμένο από τον ";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -593,8 +569,9 @@ class TranslatorGreek : public Translator
         case ClassDef::Protocol:   result+=" Πρωτοκόλλου "; break;
         case ClassDef::Category:   result+=" Κατηγορίας "; break;
         case ClassDef::Exception:  result+=" Εξαίρεσης "; break;
+        default: break;
       }
-	  result+=clName;
+      result+=clName;
       return result;
     }
 
@@ -751,18 +728,13 @@ class TranslatorGreek : public Translator
         case ClassDef::Protocol:   result+="αυτό το πρωτόκολλο"; break;
         case ClassDef::Category:   result+="αυτή την κατηγορία"; break;
         case ClassDef::Exception:  result+="αυτή την εξαίρεση"; break;
+        default: break;
       }
       result+=" δημιουργήθηκε απο τ";
       if (single) result+="ο ακόλουθο αρχείο:"; else result+="α ακόλουθα αρχεία:";
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Αλφαβητική Λίστα"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1065,16 +1037,6 @@ class TranslatorGreek : public Translator
       return "Λίστα Δοκιμαστικών";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "Μέδοδοι DCOP";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1183,11 +1145,10 @@ class TranslatorGreek : public Translator
 
 
     /*! Used as ansicpg for RTF fcharset
-     *  \see trRTFansicp() for a table of possible values.
      */
     virtual QCString trRTFCharSet()
     {
-      return "0";
+      return "161";
     }
 
     /*! Used as header RTF general index */
@@ -1418,14 +1379,6 @@ class TranslatorGreek : public Translator
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Αναζήτηση για";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1651,6 +1604,7 @@ class TranslatorGreek : public Translator
         case ClassDef::Protocol:   result+=" Πρωτόκολλο"; break;
         case ClassDef::Category:   result+=" Κατηγορία"; break;
         case ClassDef::Exception:  result+=" Εξαίρεση"; break;
+        default: break;
       }
       if (isTemplate) result+=" Πρότυπο";
       result+=" Δήλωση";
@@ -1718,6 +1672,7 @@ class TranslatorGreek : public Translator
         case ClassDef::Protocol:   result+="αυτό το πρωτόκολλο"; break;
         case ClassDef::Category:   result+="αυτή την κατηγορία"; break;
         case ClassDef::Exception:  result+="αυτή την εξαίρεση"; break;
+        default: break;
       }
       result+=" δημιουργήθηκε από ";
       if (single) result+="το παρακάτω αρχείο:"; else result+="τα παρακάτω αρχεία:";
@@ -1789,12 +1744,6 @@ class TranslatorGreek : public Translator
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Διάγραμμα εξάρτησης φακέλου για το "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
